/*%
   Java host software API of ZTEX SDK
   Copyright (C) 2009-2023 ZTEX GmbH.
   http://www.ztex.de
   
   This Source Code Form is subject to the terms of the Mozilla Public
   License, v. 2.0. If a copy of the MPL was not distributed with this file,
   You can obtain one at http://mozilla.org/MPL/2.0/.

   Alternatively, the contents of this file may be used under the terms
   of the GNU General Public License Version 3, as described below:

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License version 3 as
   published by the Free Software Foundation.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, see http://www.gnu.org/licenses/.
%*/

package ztex;

import org.usb4java.*;

/** * An exception generated by an object that has a name (for better logging). */
public class ZtexException extends Exception {

/** 
  * Composes a message.
  * @param obj The named object that generated the exception (can be null).
  * @param msg The error message.
  */
    private static String composeMsg (Object obj, String msg) {
	if ( (msg==null) && (msg.length()==0) ) msg = "Unknown error";
	String n = null;
	if ( obj != null ) {
	    if ( obj instanceof HasName ) n = ((HasName) obj).name();
	    else if ( obj instanceof Device ) n = ZtexDevice1.name( (Device) obj );
	    else if ( obj instanceof String ) n = (String) obj;
	}
	if ( (n==null) || (n.length()==0) ) return msg;
	return n + ": " + msg;
    }
        
/** 
  * Constructs an instance from the given error message.
  * @param obj The named object that generataed the exceptiopn (can be null).
  * @param msg The error message.
  */
    public ZtexException (Object obj, String msg) {
	super ( composeMsg(obj,msg) );
    }
}    
